| s4pca_reconstruct | R Documentation |
Reconstructs the training data or a new matrix using the score subspace and
reconstruction coefficients learned by a public S4PCA call to msma.
s4pca_reconstruct(object, newdata = NULL, scaled = FALSE)
object |
an object of class |
newdata |
optional numeric matrix with the same variables as the fitted X. |
scaled |
logical; if TRUE, return reconstruction on the standardized scale. |
a reconstructed numeric matrix.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.